#!/bin/bash

# tester.sh
#
# Author: Moreno Marzolla <moreno.marzolla(at)unibo.it>
# Last updated: 2018-09-21
#
# This program can be used to run the tests shown in the paper
# "Parallel Implementations of Cellular Automata for Traffic Models"
#
# This program prints to stdout the program name being tested, and the
# execution times of five independent runs. The number of runs, and
# the other parameters, can be changed by setting the environment
# variables below. To replicate the data on the paper, you might run:
#
# GRIDSIZE=1024 ./tester.sh > times-1024.txt
# GRIDSIZE=2048 ./tester.sh > times-2048.txt
# GRIDSIZE=4096 ./tester.sh > times-4096.txt

GRIDSIZE=${GRIDSIZE:-2048} # grid size
RHO=${RHO:-0.3}         # vehicle density
NSTEPS=${NSTEPS:-1024}  # number of steps
NREP=${NREP:-5}         # number of runs for each test

PRGS="traffic traffic-halo omp-traffic simd-traffic omp-simd-traffic cuda-traffic cuda-traffic-shared cuda-traffic-shared-2"
CORES=`cat /proc/cpuinfo | grep processor | wc -l`

echo "# `uname -a`"
echo "# NSTEPS=$NSTEPS"
echo "# RHO=$RHO"
echo "# GRIDSIZE=$GRIDSIZE"
for prg in $PRGS; do
    if [ -f "$prg" ]; then
        echo -n "$prg "
        for r in `seq $NREP`; do
            CMD="./$prg $NSTEPS $RHO $GRIDSIZE"
            TT=`eval $CMD 2>&1 | cut -d ' ' -f 6`
            echo -n "$TT "
        done
        echo
    fi
done

    
